@@ -52,7 +52,7 @@
 map.FLightR.ggmap<-function(Result, dates=NULL, plot.cloud=TRUE, map.options=NULL, plot.options=NULL, save.options=NULL, zoom="auto", return.ggobj=FALSE, seasonal.colors=TRUE, seasonal.donut.location='topleft', seasonal.donut.proportion=0.5, save=TRUE) {
 if (!is.null(plot.options)) warning("plot options are not in use yet. Let me know what you would like to have here.")
 
-if (utils::packageVersion('ggmap')[1]<2.7) { stop('map.FLightR.ggmap function works only with ggmap >= 2.7.x') }
+if (utils::packageVersion('ggmap')[1]<'2.7') { stop('map.FLightR.ggmap function works only with ggmap >= 2.7.x') }
 if (!ggmap::has_google_key()) stop('From August 2018 Google allows to use Google maps only for users with the API key, please get one and proceed as described here: http://ornithologyexchange.org/forums/topic/38315-mapflightrggmap-error/')
 # dates should be a data.frame with first point - starting dates and last column end dates for periods
 
@@ -230,7 +230,7 @@ options('ggmap'= Opt$ggmap)
 #' This function plots result by latitude and longitude in either vertical or horizontal layout.
 #' @param Result FLightR result object obtained from \code{\link{run.particle.filter}}
 #' @param scheme either 'vertical' or 'horizontal' layouts
-#' return 'NULL'
+#' @return 'NULL'
 #' @examples
 #' File<-system.file("extdata", "Godwit_TAGS_format.csv", package = "FLightR")
 #' # to run example fast we will cut the real data file by 2013 Aug 20
@@ -416,7 +416,7 @@ get_time_spent_buffer<-function(Result, dates=NULL, percentile=0.5, r=NULL) {
   }
   }
   #Buff_comb_simpl<-rgeos::gSimplify(Buff_comb, tol=0.01, topologyPreserve=TRUE)
-  Buff_comb_simpl<-sf::st_simplify(Buff_comb,preserveTopology = FALSE, dTolerance = 0.01)
+  Buff_comb_simpl<-sf::st_simplify(Buff_comb, dTolerance = 0.01)
   return(list(Buffer=Buff_comb_simpl, nPoints=length(Points_selected))) # Points before
   }
 
@@ -436,8 +436,6 @@ get_time_spent_buffer<-function(Result, dates=NULL, percentile=0.5, r=NULL) {
 #' @param background if provided will be used as a background. Must be created by \code{link[ggmap]{get_map}}
 #' @param plot should function produce a plot?
 #' @param save should function save results with \code{\link[ggplot2]{ggsave}}?
-#' @param add.scale.bar will add scalebar with the \code{\link[ggsn]{scalebar}}
-#' @param scalebar.options options passed to \code{\link[ggsn]{scalebar}}
 #' @return list with two parts 
 #'         \item{res_buffers}{spatial buffers for defined probability values}
 #'         \item{p}{\code{\link[ggplot2]{ggplot}} object}
@@ -474,9 +472,9 @@ get_time_spent_buffer<-function(Result, dates=NULL, percentile=0.5, r=NULL) {
 #'
 #' @author Eldar Rakhimberdiev
 #' @export plot_util_distr
-plot_util_distr<-function(Result, dates=NULL, map.options=NULL, percentiles=c(0.4, 0.6, 0.8), zoom="auto", geom_polygon.options=NULL, save.options=NULL, color.palette=NULL, use.palette=TRUE, background=NULL, plot=TRUE, save=TRUE, add.scale.bar=FALSE, scalebar.options=NULL) {
+plot_util_distr<-function(Result, dates=NULL, map.options=NULL, percentiles=c(0.4, 0.6, 0.8), zoom="auto", geom_polygon.options=NULL, save.options=NULL, color.palette=NULL, use.palette=TRUE, background=NULL, plot=TRUE, save=TRUE) {
 
-if (utils::packageVersion('ggmap')[1]<2.7) {stop('plot_util_distr function works only with ggmap >= 2.7.x')}
+if (utils::packageVersion('ggmap')[1]<'2.7') {stop('plot_util_distr function works only with ggmap >= 2.7.x')}
 
 if (!ggmap::has_google_key()) stop('From August 2018 Google allows to use Google maps only for users with the API key, please get one and proceed as described here: http://ornithologyexchange.org/forums/topic/38315-mapflightrggmap-error/')
 
@@ -597,10 +595,12 @@ for (percentile in percentiles) {
 	geom_path.options$linetype<- geom_polygon.options$linetype
 	geom_polygon.options$linetype=0
 	
-	geom_polygon.options$mapping=ggplot2::aes(x=long, y=lat, group=group)
-	geom_path.options$mapping=geom_polygon.options$mapping
+	#geom_polygon.options$mapping=ggplot2::aes(x=long, y=lat, group=group)
+	#geom_path.options$mapping=geom_polygon.options$mapping
 	
-	geom_polygon.options$data=buff_cur
+	#geom_polygon.options$data=buff_cur
+	geom_polygon.options$data=sf::st_coordinates(buff_cur) [, c(1:2)]|> data.frame() |> stats::setNames(c('lon', 'lat' ))
+    
 	geom_path.options$data=geom_polygon.options$data
 	p<-p+do.call(ggplot2::geom_polygon, geom_polygon.options)
 	p<-p+do.call(ggplot2::geom_path, geom_path.options)
@@ -609,22 +609,6 @@ for (percentile in percentiles) {
 	
 	}
     if (plot) print(p)
-	if (add.scale.bar) {
-	if (is.null(scalebar.options)) scalebar.options=list()
-	BB<-attr(background, 'bb')
-
-	if (is.null(scalebar.options$dist)) scalebar.options$dist=max(((abs(as.numeric(BB[1, 4])-as.numeric(BB[1, 2]))*100*0.1)%/%25)*25, 25)
-	
-	scalebar.options$dd2km <- TRUE
-	scalebar.options$model <- 'WGS84'
-	if (is.null(scalebar.options$location)) scalebar.options$location <- 'topright'
-	scalebar.options$y.min=as.numeric(BB[1, 1])+(as.numeric(BB[1, 3])-as.numeric(BB[1, 1]))*0.05
-	scalebar.options$y.max=as.numeric(BB[1, 3])-(as.numeric(BB[1, 3])-as.numeric(BB[1, 1]))*0.05
-	scalebar.options$x.min=as.numeric(BB[1, 2])-(as.numeric(BB[1, 2])-as.numeric(BB[1, 4]))*0.05
-	scalebar.options$x.max=as.numeric(BB[1, 4])+(as.numeric(BB[1, 2])-as.numeric(BB[1, 4]))*0.05
-	
-	p=p+do.call(ggsn::scalebar, scalebar.options)
-	}
 	
 	if (save) {
 	   if (is.null(save.options))  save.options=list()
@@ -746,4 +730,4 @@ get_utilisation_points<-function(Result, twilights.index, percentile) {
   Points_selected<-(1:length(All.Points))[Points]
   return(Points_selected) 
 }
- 
+ 
\ No newline at end of file
