@@ -59,8 +59,7 @@ test_that('parallel setup works works',  {
 }
 )
 
-
-test_that('run.particle.filter works',  {
+test_that('run.particle.filter works without outlier detection',  {
    File<-system.file("extdata", "Godwit_TAGS_format.csv", package = "FLightR")
    Proc.data<-get.tags.data(File, end.date=as.POSIXct('2013-07-02', tz='GMT'))
    Calibration.periods<-data.frame(
@@ -76,5 +75,23 @@ test_that('run.particle.filter works',  {
            nParticles=1e3, known.last=TRUE, check.outliers=FALSE)
    expect_equal(dim(Result$Results$Quantiles), c(27, 21))
    expect_equal(dim(Result$Results$Movement.results), c(27, 12))
-   }
-)
+   } ) 
+   
+test_that('run.particle.filter works with outlier detection',  {
+   File<-system.file("extdata", "Godwit_TAGS_format.csv", package = "FLightR")
+   Proc.data<-get.tags.data(File, end.date=as.POSIXct('2013-07-02', tz='GMT'))
+   Calibration.periods<-data.frame(
+        calibration.start=NA,
+        calibration.stop=as.POSIXct("2013-08-20", tz='GMT'),
+		lon=5.43, lat=52.93) 
+   Calibration<-make.calibration(Proc.data, Calibration.periods, likelihood.correction=FALSE)
+   Grid<-make.grid(left=0, bottom=50, right=10, top=56,
+     distance.from.land.allowed.to.use=c(-Inf, Inf),
+     distance.from.land.allowed.to.stay=c(-Inf, Inf))
+   all.in<-make.prerun.object(Proc.data, Grid, start=c(5.43, 52.93), Calibration=Calibration, threads=1)
+   Result<-run.particle.filter(all.in, threads=1,
+           nParticles=1e3, known.last=TRUE, check.outliers=TRUE)
+   expect_equal(dim(Result$Results$Quantiles), c(27, 21))
+   expect_equal(dim(Result$Results$Movement.results), c(27, 12))
+   } )
+
